# Generated by Django 4.2.3 on 2023-07-26 18:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('easyaudit', '0017_alter_requestevent_datetime'),
    ]

    operations = [
        migrations.RenameIndex(
            model_name='crudevent',
            new_name='easyaudit_c_object__82020b_idx',
            old_fields=('object_id', 'content_type'),
        ),
    ]
