# Generated by Django 4.1.1 on 2022-09-25 00:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('easyaudit', '0016_alter_crudevent_event_type'),
    ]

    operations = [
        migrations.AlterField(
            model_name='requestevent',
            name='datetime',
            field=models.DateTimeField(auto_now_add=True, db_index=True, verbose_name='Date time'),
        ),
    ]
