# Generated by Django 3.0.6 on 2020-05-13 00:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('easyaudit', '0013_auto_20190723_0126'),
    ]

    operations = [
        migrations.AlterField(
            model_name='crudevent',
            name='object_id',
            field=models.CharField(max_length=255),
        ),
    ]
